@@ -201,6 +201,8 @@ def execute_query(myuser, mypassword, myhost, database, cve=None, score=None, da
 def query_for_cwe(myuser, mypassword, myhost, database, cve, out=False):
     query = "SELECT * FROM cve_problem WHERE cve = %s"
 
+    selected_cwe = None
+
     with connect(dbname=database, user=myuser, host=myhost, password=mypassword) as con:
         with con.cursor() as cur:
             try:
@@ -219,4 +221,6 @@ def query_for_cwe(myuser, mypassword, myhost, database, cve, out=False):
                         print(answer)
 
             except(Exception, psycopg2.DatabaseError) as error:
-                print("Error while Querying Database", error)
\ No newline at end of file
+                print("Error while Querying Database", error)
+
+    return selected_cwe
